#[non_exhaustive]pub struct PossiblyRedactedSpaceChildEventContent {
pub via: Option<Vec<OwnedServerName>>,
pub order: Option<OwnedSpaceChildOrder>,
pub suggested: bool,
}events only.Expand description
The possibly redacted form of SpaceChildEventContent.
This type is used when it’s not obvious whether the content is redacted or not.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.via: Option<Vec<OwnedServerName>>List of candidate servers that can be used to join the room.
order: Option<OwnedSpaceChildOrder>Provide a default ordering of siblings in the room list.
Rooms are sorted based on a lexicographic ordering of the Unicode codepoints of the
characters in order values. Rooms with no order come last, in ascending numeric order
of the origin_server_ts of their m.room.create events, or ascending lexicographic order of
their room_ids in case of equal origin_server_ts. orders which are not strings, or do
not consist solely of ascii characters in the range \x20 (space) to \x7E (~), or
consist of more than 50 characters, are forbidden and the field should be ignored if
received.
During deserialization, this field is set to None if it is invalid.
suggested: boolSpace admins can mark particular children of a space as “suggested”.
This mainly serves as a hint to clients that that they can be displayed differently, for
example by showing them eagerly in the room list. A child which is missing the suggested
property is treated identically to a child with "suggested": false. A suggested child may
be a room or a subspace.
Defaults to false.